@@ -3,9 +3,12 @@ from abstract_utilities.json_utils import (json,
                                            get_desired_key_values,
                                            makeParams,
                                            dump_if_json,
-                                           make_list)
+                                           make_list
+                                           )
 import inspect
+from flask import jsonify
 from abstract_utilities.log_utils import print_or_log
+from app_utils import *
 def get_proper_kwargs(strings, **kwargs):
     # Convert the provided strings to lowercase for case-insensitive matching
     strings_lower = [string.lower() for string in strings]
@@ -124,7 +127,7 @@ def get_json_call_response(value, status_code, data=None,logMsg=None):
         logMsg = logMsg or "success"
         initialize_call_log(value=value,
                             data=data,
-                            message=logMsg,
+                            logMsg=logMsg,
                             log_level='info')
     else:
         response_body["success"] = False
@@ -132,7 +135,7 @@ def get_json_call_response(value, status_code, data=None,logMsg=None):
         logMsg = logMsg or f"ERROR: {logMsg}"
         initialize_call_log(value=value,
                             data=data,
-                            message=logMsg,
+                            logMsg=logMsg,
                             log_level='error')
     return jsonify(response_body), status_code
 
@@ -165,7 +168,7 @@ def initialize_call_log(value=None,
         # Avoid reference cycles
         del stack
 
-    message = message or "initializing"
+    logMsg = logMsg or "initializing"
     full_message = (
         f"{logMsg}\n"
         f"calling_function: {caller_name}\n"
